@@ -16,7 +16,8 @@ import (
 func main() {
 	flag.Parse()
 
-	r, err := spf.CheckHost(net.ParseIP(flag.Arg(0)), flag.Arg(1))
+	r, err := spf.CheckHostWithSender(
+		net.ParseIP(flag.Arg(0)), "", flag.Arg(1))
 	fmt.Println(r)
 	fmt.Println(err)
 }
