@@ -56,7 +56,6 @@ package aliases
 import (
 	"bufio"
 	"context"
-	"expvar"
 	"fmt"
 	"io"
 	"os"
@@ -66,13 +65,15 @@ import (
 	"time"
 
 	"blitiri.com.ar/go/chasquid/internal/envelope"
+	"blitiri.com.ar/go/chasquid/internal/expvarom"
 	"blitiri.com.ar/go/chasquid/internal/normalize"
 	"blitiri.com.ar/go/chasquid/internal/trace"
 )
 
 // Exported variables.
 var (
-	hookResults = expvar.NewMap("chasquid/aliases/hookResults")
+	hookResults = expvarom.NewMap("chasquid/aliases/hookResults",
+		"result", "count of aliases hook results, by hook and result")
 )
 
 // Recipient represents a single recipient, after resolving aliases.
@@ -453,12 +454,15 @@ func (v *Resolver) runExistsHook(addr string) bool {
 	ctx, cancel := context.WithTimeout(context.Background(), 5*time.Second)
 	defer cancel()
 	cmd := exec.CommandContext(ctx, v.ExistsHook, addr)
-	err := cmd.Run()
+
+	out, err := cmd.CombinedOutput()
+	tr.Debugf("output: %q", string(out))
 	if err != nil {
 		tr.Debugf("not exists: %v", err)
 		hookResults.Add("exists:false", 1)
 		return false
 	}
+
 	tr.Debugf("exists")
 	hookResults.Add("exists:true", 1)
 	return true
