@@ -51,6 +51,8 @@ var (
 		"result", "incoming security level check results")
 	hookResults = expvarom.NewMap("chasquid/smtpIn/hookResults",
 		"result", "count of hook invocations, by result")
+	wrongProtoCount = expvarom.NewMap("chasquid/smtpIn/wrongProtoCount",
+		"command", "count of commands for other protocols")
 )
 
 var (
@@ -145,9 +147,6 @@ type Conn struct {
 	// Have we successfully completed AUTH?
 	completedAuth bool
 
-	// How many times have we attempted AUTH?
-	authAttempts int
-
 	// Authenticated user and domain, empty if !completedAuth.
 	authUser   string
 	authDomain string
@@ -275,10 +274,18 @@ loop:
 		case "QUIT":
 			_ = c.writeResponse(221, "2.0.0 Be seeing you...")
 			break loop
+		case "GET", "POST", "CONNECT":
+			// HTTP protocol detection, to prevent cross-protocol attacks
+			// (e.g. https://alpaca-attack.com/).
+			wrongProtoCount.Add(cmd, 1)
+			c.tr.Errorf("http command, closing connection")
+			_ = c.writeResponse(502,
+				"5.7.0 You hear someone cursing shoplifters")
+			break loop
 		default:
 			// Sanitize it a bit to avoid filling the logs and events with
 			// noisy data. Keep the first 6 bytes for debugging.
-			cmd = fmt.Sprintf("unknown<%.6s>", cmd)
+			cmd = fmt.Sprintf("unknown<%.6q>", cmd)
 			code = 500
 			msg = "5.5.1 Unknown command"
 		}
@@ -291,8 +298,10 @@ loop:
 				// Be verbose about errors, to help troubleshooting.
 				c.tr.Errorf("%s failed: %d  %s", cmd, code, msg)
 
+				// Close the connection after 3 errors.
+				// This helps prevent cross-protocol attacks.
 				errCount++
-				if errCount > 10 {
+				if errCount >= 3 {
 					// https://tools.ietf.org/html/rfc5321#section-4.3.2
 					c.tr.Errorf("too many errors, breaking connection")
 					_ = c.writeResponse(421, "4.5.0 Too many errors, bye")
@@ -578,7 +587,14 @@ func (c *Conn) RCPT(params string) (code int, msg string) {
 			return 550, "5.1.3 Destination address is invalid"
 		}
 
-		if !c.userExists(addr) {
+		ok, err := c.userExists(addr)
+		if err != nil {
+			c.tr.Errorf("error checking if user %q exists: %v", addr, err)
+			maillog.Rejected(c.remoteAddr, c.mailFrom, []string{addr},
+				fmt.Sprintf("error checking if user exists: %v", err))
+			return 451, "4.4.3 Temporary error checking address"
+		}
+		if !ok {
 			maillog.Rejected(c.remoteAddr, c.mailFrom, []string{addr},
 				"local user does not exist")
 			return 550, "5.1.1 Destination address is unknown (user does not exist)"
@@ -1009,11 +1025,6 @@ func (c *Conn) AUTH(params string) (code int, msg string) {
 		return 503, "5.5.1 You are already wearing that!"
 	}
 
-	if c.authAttempts > 3 {
-		return 503, "5.7.8 Too many attempts, go away"
-	}
-	c.authAttempts++
-
 	// We only support PLAIN for now, so no need to make this too complicated.
 	// Params should be either "PLAIN" or "PLAIN <response>".
 	// If the response is not there, we reply with 334, and expect the
@@ -1081,11 +1092,11 @@ func (c *Conn) resetEnvelope() {
 	c.spfError = nil
 }
 
-func (c *Conn) userExists(addr string) bool {
+func (c *Conn) userExists(addr string) (bool, error) {
 	var ok bool
 	addr, ok = c.aliasesR.Exists(addr)
 	if ok {
-		return true
+		return true, nil
 	}
 
 	// Note we used the address returned by the aliases resolver, which has
@@ -1093,11 +1104,7 @@ func (c *Conn) userExists(addr string) bool {
 	// look up "user" in our databases if the domain is local, which is what
 	// we want.
 	user, domain := envelope.Split(addr)
-	ok, err := c.authr.Exists(user, domain)
-	if err != nil {
-		c.tr.Errorf("error checking if user %q exists: %v", addr, err)
-	}
-	return ok
+	return c.authr.Exists(user, domain)
 }
 
 func (c *Conn) readCommand() (cmd, params string, err error) {
