@@ -214,25 +214,25 @@ func TestBrokenAuth(t *testing.T) {
 }
 
 func TestWrongMailParsing(t *testing.T) {
-	c := mustDial(t, ModeSMTP, false)
-	defer c.Close()
-
 	addrs := []string{"from", "a b c", "a @ b", "<x>", "<x y>", "><"}
-
 	for _, addr := range addrs {
+		c := mustDial(t, ModeSMTP, false)
+
 		if err := c.Mail(addr); err == nil {
 			t.Errorf("Mail not failed as expected with %q", addr)
 		}
-	}
 
-	if err := c.Mail("from@plain"); err != nil {
-		t.Errorf("Mail: %v", err)
-	}
-
-	for _, addr := range addrs {
-		if err := c.Rcpt(addr); err == nil {
-			t.Errorf("Rcpt not failed as expected with %q", addr)
+		if err := c.Mail("from@plain"); err != nil {
+			t.Errorf("Mail: %v", err)
 		}
+
+		for _, addr := range addrs {
+			if err := c.Rcpt(addr); err == nil {
+				t.Errorf("Rcpt not failed as expected with %q", addr)
+			}
+		}
+
+		c.Close()
 	}
 }
 
@@ -308,7 +308,7 @@ func TestTooManyRecipients(t *testing.T) {
 	}
 }
 
-func TestRcptFailsExistsCheck(t *testing.T) {
+func TestRcptBrokenExists(t *testing.T) {
 	c := mustDial(t, ModeSMTP, true)
 	defer c.Close()
 
@@ -320,6 +320,24 @@ func TestRcptFailsExistsCheck(t *testing.T) {
 	if err == nil {
 		t.Errorf("Accepted RCPT with broken Exists")
 	}
+	expect := "451 4.4.3 Temporary error checking address"
+	if err.Error() != expect {
+		t.Errorf("RCPT returned unexpected error %q", err.Error())
+	}
+}
+
+func TestRcptUserDoesNotExist(t *testing.T) {
+	c := mustDial(t, ModeSMTP, true)
+	defer c.Close()
+
+	if err := c.Mail("from@localhost"); err != nil {
+		t.Fatalf("Mail: %v", err)
+	}
+
+	err := c.Rcpt("doesnotexist@localhost")
+	if err == nil {
+		t.Errorf("Accepted RCPT for non-existent user")
+	}
 	expect := "550 5.1.1 Destination address is unknown (user does not exist)"
 	if err.Error() != expect {
 		t.Errorf("RCPT returned unexpected error %q", err.Error())
