@@ -3,6 +3,7 @@ package trace
 
 import (
 	"fmt"
+	"net/http"
 	"strconv"
 
 	"blitiri.com.ar/go/log"
@@ -10,6 +11,15 @@ import (
 	nettrace "golang.org/x/net/trace"
 )
 
+func init() {
+	// golang.org/x/net/trace has its own authorization which by default only
+	// allows localhost. This can be confusing and limiting in environments
+	// which access the monitoring server remotely.
+	nettrace.AuthRequest = func(req *http.Request) (any, sensitive bool) {
+		return true, true
+	}
+}
+
 // A Trace represents an active request.
 type Trace struct {
 	family string
